#
# spec file for package oxipng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           oxipng
Version:        9.1.5
Release:        1.1
Summary:        Multithreaded lossless PNG optimizer
License:        MIT
URL:            https://github.com/oxipng/oxipng
Source0:        %{name}-%{version}.tar
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libdeflate)

%description
Oxipng is a multithreaded lossless PNG compression optimizer. It can be used
via a command-line interface or as a library in other Rust programs.

%prep
%autosetup -a1

%build
%define __cargo_common_opts %{?_smp_mflags} --features "sanity-checks system-libdeflate"
%{cargo_build}
%{__cargo} run --manifest-path ./xtask/Cargo.toml -- mangen

%install
%{cargo_install}
install -t %{buildroot}%{_mandir}/man1/ -D -p -m 0644 target/xtask/mangen/manpages/oxipng.1

%check
%{cargo_test}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%changelog
* Fri Jul  4 2025 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update to version 9.1.5:
  * Add --sequential option to process files sequentially rather
    than in parallel.
  * Update to latest Zopfli with greatly improved performance.
  * Reduce memory usage.
  * Correct handling of grayscale conversion when ICC profile is
    present.
* Wed Mar 12 2025 Enrico Belleri <kilgore.trout@idesmi.eu>
- Enable features:
  * sanity-checks
  * system-libdeflate:
    use system deflate libraries
* Thu Feb 27 2025 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update to version 9.1.4:
  * Improve optimization of APNG files (reductions still not
    supported yet).
  * Improve reductions for small images and ensure consistent
    results for repeat runs.
  * Add feature system-libdeflate to use the system-installed
    version of libdeflate.
  * Strip C2PA metadata by default.
  * Add --zi option to control the number of Zopfli iterations.
  * Allow setting compression level to 0.
  * Improve filtering performance for some images.
  * Move man page generation to an xtask.
  * Fix --nx still applying deinterlacing by default.
  * Fix optimized APNGs not being compatible with some programs.
* Tue Apr 23 2024 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update to version 9.1.1:
  * Change man page generation path to resolve issue with cargo publish
* Mon Apr 22 2024 Enrico Belleri <kilgore.trout@idesmi.eu>
- Add man pages
* Sun Apr 21 2024 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update to version 9.1.0:
  * Add --keep display equivalent to --strip safe.
  * Add modified zeng palette sorting method, improving optimization of indexed images.
  * If only one filter is specified, guarantee to only use this one.
  * Evaluate low-depth indexed even if low-depth grayscale was already achieved.
  * Fix battiato palette sorting method not being used if the input was not already indexed.
  * Fix rare crash caused by a truncated palette.
  * Reduce size of binaries.
  * Add man page generation.
* Fri Nov 10 2023 kilgore.trout@idesmi.eu
- Update to version 9.0.0:
  * Overhaul help
  * Tidy some issue tests
  * Add test
  * Combine palette reduction and sorting
  * Update `zopfli` to v0.8.0
  * Bump actions/checkout from 3 to 4
  * Remove libdeflate slack space no longer needed
  * Update libdeflater
  * Remove `backup` and `check` options
* Mon Jul 31 2023 Marcus Rueckert <mrueckert@suse.de>
- Replace rust-packaging with cargo-packaging after the rename
* Sat Jan 14 2023 Marcus Rueckert <mrueckert@suse.de>
- initial package
